@@ -58,9 +58,10 @@ from python_framework.api.src.annotation.ServiceAnnotation import *
 from python_framework.api.src.annotation.RepositoryAnnotation import *
 from python_framework.api.src.annotation.client.ClientAnnotation import *
 from python_framework.api.src.annotation.client.HttpClientAnnotation import *
+from python_framework.api.src.annotation.client.ListenerAnnotation import *
+from python_framework.api.src.annotation.client.ProducerAnnotation import *
 from python_framework.api.src.annotation.ValidatorAnnotation import *
 from python_framework.api.src.annotation.MapperAnnotation import *
 from python_framework.api.src.annotation.ConverterAnnotation import *
 from python_framework.api.src.annotation.HelperAnnotation import *
 from python_framework.api.src.annotation.GlobalExceptionAnnotation import *
-from python_framework.api.src.annotation.ListenerAnnotation import *
